"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchAndRetry = void 0;
const DEFAULT_RETRY_DELAY = 5000;
const MIN_RETRY_DELAY = 1000;
const MAX_RETRY = 5;
const RATE_LIMIT_HEADER = 'X-RateLimit-Reset';
const fetchAndRetry = async (fetcher, url, options, attemptsLeft = MAX_RETRY) => {
    try {
        const res = await fetcher(url, options);
        if (attemptsLeft > 0 && (res.status === 429 || res.status >= 500)) {
            const delay = getDelay(res.headers.get(RATE_LIMIT_HEADER));
            await sleep(delay);
            return (0, exports.fetchAndRetry)(fetcher, url, options, attemptsLeft - 1);
        }
        return res;
    }
    catch (error) {
        if (attemptsLeft === 0) {
            throw error;
        }
        const delay = getDelay();
        await sleep(delay);
        return (0, exports.fetchAndRetry)(fetcher, url, options, attemptsLeft - 1);
    }
};
exports.fetchAndRetry = fetchAndRetry;
const getDelay = (rateLimitReset) => {
    if (!rateLimitReset) {
        return DEFAULT_RETRY_DELAY;
    }
    return Math.max(Number(rateLimitReset) * 1000 - Date.now(), MIN_RETRY_DELAY);
};
const sleep = (ms) => new Promise((resolve) => {
    setTimeout(resolve, ms);
});
